set terminal pdfcairo enhanced color transparent rounded

set key outside center top horizontal reverse Left samplen 2
unset border
set xtics scale 0
set ytics scale 0
set grid ytics linewidth 1 linetype -1

set style line 1 lt 1 lc rgbcolor "#3465a4" lw 2.5 pt 7 ps 1
set style line 2 lt 1 lc rgbcolor "#edd400" lw 2.5 pt 7 ps 1
set style line 3 lt 1 lc rgbcolor "#888a85" lw 2.5 pt 5 ps 1
set style line 4 lt 1 lc rgbcolor "#f57900" lw 2.5 pt 5 ps 1
set style line 5 lt 1 lc rgbcolor "#ad7fa8" lw 2.5 pt 9 ps 1
set style line 6 lt 1 lc rgbcolor "#4e9a06" lw 2.5 pt 9 ps 1
set style line 7 lt 1 lc rgbcolor "#ef2929" lw 2.5 pt 1 ps 1
set style line 8 lt 1 lc rgbcolor "#5c3566" lw 2.5 pt 1 ps 1
set style line 9 lt 1 lc rgbcolor "#c17d11" lw 2.5 pt 3 ps 1
set style line 10 lt 1 lc rgbcolor "#dce775" lw 2.5 pt 3 ps 1

set key off
set style fill solid
set style data histogram
set style histogram clustered gap 1
set boxwidth 0.6


set title "約100万件のtweetに対して\n1万回のフレーズ検索にかかった時間\n（グラフが短いほど速い）" \
    font "monospace,10" \
    offset 0,1.5
set object 10 \
    rectangle \
    from screen 0.1, screen 0.59 rto 0.37, 0.15 \
    fillstyle solid \
    border -1 \
    front
set label 10 \
    "MySQL: 5.6.3-labs-innodb-fts\ngroonga: 1.2.5\ngroongaストレージエンジン: 0.9" \
    at screen 0.12, screen 0.7 \
    left front
set xtics font "monospace,9"

set xlabel font "monospace,10"
# set xlabel "ストレージエンジン"
set ylabel "検索時間 (秒)" font "monospace,10"
set tmargin 6.5
set bmargin 7

set output "fulltext-phrase-search-without-mroonga-wrapper-mode.pdf"
plot "fulltext-phrase-search-without-mroonga-wrapper-mode.dat" \
     using 2:xticlabels(1) linestyle 1

set bmargin 9
set output "fulltext-phrase-search.pdf"
plot [-0.5:3.5] "fulltext-phrase-search.dat" using 2:xticlabels(1) linestyle 1


# geo
set title "約1100万件の番地データに対して\n千回のMBRContains + ORDER BY検索にかかった時間\n（グラフが短いほど速い）" \
    font "monospace,10" \
    offset 0,1.5
set object 10 \
    rectangle \
    from screen 0.15, screen 0.59 rto 0.39, 0.15 \
    fillstyle solid \
    border -1 \
    front
set label 10 \
    "MySQL: 5.5.13\ngroonga: 1.2.7\ngroongaストレージエンジン: 1.0.1" \
    at screen 0.17, screen 0.7 \
    left front
set xtics font "monospace,9"
set label 11 \
    "国土交通相の位置参照情報ダウンロードサービスから\nダウンロードした2010年版データを利用\nhttp://nlftp.mlit.go.jp/isj/" \
    at screen 0.01, screen 0.1 \
    left front \
    font "monospace,5"

set bmargin 9
set output "geo-search.pdf"
plot "geo-search.dat" using 2:xticlabels(1) linestyle 1

set output "geo-search-without-mroonga-wrapper-mode.pdf"
plot "geo-search-without-mroonga-wrapper-mode.dat" using 2:xticlabels(1) linestyle 1

set label 11 ""

# update
set title "98万件のtweetが保存されている状態で\n2万件のtweetを追加したときの更新スループット\n（グラフが長いほど速い）" \
    font "monospace,10" \
    offset 0,1.5
set object 10 \
    rectangle \
    from screen 0.55, screen 0.56 rto 0.37, 0.175 \
    fillstyle solid \
    border -1 \
    front
set label 10 \
    "MySQL: 5.6.3-labs-innodb-fts\ngroonga: 1.2.5\ngroongaストレージエンジン: 0.9\nSphinx: 1.10-beta (r2420)" \
    at screen 0.57, screen 0.7 \
    left front
set xtics font "monospace,9"
set ylabel "更新スループット \n(追加レコード数/秒)" font "monospace,10"

set tmargin 7
set bmargin 6
set output "update-without-mroonga-wrapper-mode.pdf"
plot [-0.25:3.25] "update-without-mroonga-wrapper-mode.dat" using 2:xticlabels(1) linestyle 1

set tmargin 7
set bmargin 9
set output "update.pdf"
plot [-0.25:4.25] "update.dat" using 2:xticlabels(1) linestyle 1


set key on spacing 1.5
set tmargin
set bmargin 4
set xtics font ""

set title "（グラフが水平だと検索しながらの更新に強い）"
# set title "検索負荷を変えながらレコードを追加したときの\n更新スループット\n（グラフが水平だと検索しながらの更新に強い）" \
#     font "monospace,10" \
#     offset 0,1.5
set xlabel "検索負荷（クエリ数/秒）"
set object 10 \
    rectangle \
    from screen 0.55, screen 0.39 rto 0.37, 0.175 \
    fillstyle solid \
    border -1 \
    front
set label 10 \
    "MySQL: 5.6.3-labs-innodb-fts\ngroonga: 1.2.5\ngroongaストレージエンジン: 0.9\nSphinx: 1.10-beta (r2420)" \
    at screen 0.57, screen 0.53 \
    left front

set key at screen 0.19, screen 0.6 left center font "monospace,7"
set output "update-with-search.pdf"
plot [0:1100] \
     "update-with-search.dat" using 3:2 with linespoints linestyle 1 title "groongaストレージエンジン", \
     "" using 5:4 with linespoints linestyle 3 title "groongaストレージエンジン + InnoDB", \
     "" using 7:6 with linespoints linestyle 5 title "InnoDB", \
     "" using 9:8 with linespoints linestyle 7 title "MyISAM", \
     "" using 11:10 with linespoints linestyle 9 title "Sphinx"

set key at screen 0.19, screen 0.65 left center font "monospace,7"
set output "update-with-search-without-mroonga-wrapper-mode.pdf"
plot [0:1100] \
     "update-with-search.dat" using 3:2 with linespoints linestyle 1 title "groongaストレージエンジン", \
     "" using 7:6 with linespoints linestyle 5 title "InnoDB", \
     "" using 9:8 with linespoints linestyle 7 title "MyISAM", \
     "" using 11:10 with linespoints linestyle 9 title "Sphinx"
